Module config

Module config 

Configuration of the statement protocol

Constants

DEFAULT_STATEMENTS_PER_SECOND
Default maximum statements per second before rate limiting kicks in.
MAX_KNOWN_STATEMENTS
Maximum number of known statement hashes to keep for a peer.
MAX_PENDING_STATEMENTS
Maximum number of statement validation request we keep at any moment.
MAX_STATEMENT_NOTIFICATION_SIZE
Maximum allowed size for a statement notification.
STATEMENTS_BURST_COEFFICIENT
Burst capacity coefficient for the rate limiter.